@@ -182,7 +182,7 @@ class IMdata:
                 vmax_now = vmax_set
             else:
                 vmax_now = 1.2*np.nanmax(data_new)
-            ax.text(1400,1800, str(int(freq_cur)) + 'MHz',color='w')
+            ax.text(fov*0.55, fov*0.9, str(int(freq_cur)) + 'MHz',color='w')
             circle1 = plt.Circle((0,0), 960, color='r',fill=False)
             beam0 = Ellipse((-fov*0.3, -fov*0.9), b_maj, b_min, -(b_angel-solar_PA),color='w')
             
